import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Tag, Pagination, Modal,Breadcrumb } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import styles from '../../style/GoodsList.less';
import router from 'umi/router';
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import apis from '../../../services/apis';
import request from '../../../utils/request'
import AuthButton from '@/components/AuthButton';

const { Option } = Select;


function header(props) {
  // 获取初始化数据
  const [ data, setData ] = useState({})

  useEffect(() => {
    getList({ pageNum: 1, pageSize: 10 });
  },[])

  // 查询列表
  const getList = (params) => {
    request({ ...apis.carsuseFigure.customImg, params: { ...params },}).then((data) => {
        console.log(data)
        setData(data)
    })
  }
  
  // 提交事件
  const handleSubmit = (e, props) => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        getList({ pageNum: 1, pageSize: 10, ...values })
      }
    });
  }

  const changePageNum = (pageNumber) => {
    props.form.validateFields((err, values) => {
      if (!err) {
        getList({ pageNumber: pageNumber, pageSize: 10, ...values })
      }
    });
  }

  function handleReset() {
    props.form.resetFields();
    getList({ pageNum: 1, pageSize: 10 });
  }

  // 跳转到编辑商品
  const toEditCustom = (imgId) => () => {
    router.push({
      pathname: '/carouselFigure/customImg/edit',
      query: {
        imgId
      },
    });
  }

  /**
   *
   *
   * @param {*} props
   * @returns
   */
  const columns = [
    {
      title: '图片',
      dataIndex: 'imgUrl',
      key: 'imgUrl',
      align: 'center',
      render: (text, record) => <img src={record.imgUrl} className={styles.touxiang} />,
    },
    {
      title: '类型',
      dataIndex: 'imgType',
      key: 'imgType',
      align: 'center',
      render: (text, records) => (<span>{records.imgType == 'index' ? '首页分享':'推荐客户' }</span> )
    },
    {
      title: '说明',
      dataIndex: 'imgDesc',
      key: 'imgDesc',
      align: 'center',
    },
    {
      title: '操作',
      dataIndex: 'handle',
      key: 'handle',
      align: 'center',
      render: (x, row) => (
        <>
          <AuthButton name="admin.custom.put" noRight={null}>
            <span style={{ color: '#FF925C', cursor: 'pointer' }} onClick={toEditCustom(row.imgId)}>
              编辑<Icon type="form" className={styles.edit} />
            </span>
          </AuthButton>
        </>
      ),
    },
  ];

  const { getFieldDecorator } = props.form
  return (

    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        
      </Form>
      <AuthButton name="admin.custom.post" noRight={null}>
        <Button type="danger" className={styles.addBtn} onClick={toEditCustom()}>新增</Button>
      </AuthButton>
      <Table rowKey="goodsList" dataSource={data.records} columns={columns} pagination={false} />
    </>
  )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader
